---
title: TanaT-CLI-preset, A TanaT extension providing preset configurations for command line interface usage.
---

# Overview

This package provides default configurations used by TanaT CLI commands. It serves as a dependency for TanaT, containing:
- Standard workflow templates
- Metric configurations
- Function definitions
- Default data source settings

# Contributors and Contact

This developpment is part of the [AIRacles Chair](https://www.bernoulli-lab.fr/project/chaire-ai-racles/) (Inria/APHP) and is conducted in the [AIstroSight](https://team.inria.fr/aistrosight/) Inria Team.

* Arnaud Duvermy (design, core architecture, maintenance)
* Thomas Guyet (project leader, design, development of data analysis methods, documentation)

<u>Contact:</u> [thomas.guyet@inria.fr](mailto:thomas.guyet@inria.fr).


This work benefits from the advices of Mike Rye.
